@@ -7,7 +7,6 @@ var searchData=
   ['envdcp_2ehxx_4',['EnvDcp.hxx',['../a00323.html',1,'']]],
   ['envguards_2ehxx_5',['EnvGuards.hxx',['../a00308.html',1,'']]],
   ['environment_2eh_6',['environment.h',['../a00293.html',1,'']]],
-  ['environment_2ehxx_7',['Environment.hxx',['../a02512.html',1,'']]],
-  ['environment_2ehxx_8',['environment.hxx',['../a02515.html',1,'']]],
-  ['exc_5fhlp_2ehxx_9',['exc_hlp.hxx',['../a00341.html',1,'']]]
+  ['environment_2ehxx_7',['environment.hxx',['../a02516.html',1,'(Global Namespace)'],['../a02519.html',1,'(Global Namespace)']]],
+  ['exc_5fhlp_2ehxx_8',['exc_hlp.hxx',['../a00341.html',1,'']]]
 ];
