@@ -1,6 +1,6 @@
 var searchData=
 [
-  ['opcodemap_0',['OpCodeMap',['../interfacecom_1_1sun_1_1star_1_1report_1_1meta_1_1XFormulaParser.html#a8d943cfbfc5fe63e6f4a3c1e934b7bc4',1,'com::sun::star::report::meta::XFormulaParser::OpCodeMap()'],['../servicecom_1_1sun_1_1star_1_1sheet_1_1FormulaParser.html#a471ff54127cd34cf9f9807df69c5eec6',1,'com::sun::star::sheet::FormulaParser::OpCodeMap()']]],
+  ['opcodemap_0',['opcodemap',['../interfacecom_1_1sun_1_1star_1_1report_1_1meta_1_1XFormulaParser.html#a8d943cfbfc5fe63e6f4a3c1e934b7bc4',1,'com::sun::star::report::meta::XFormulaParser::OpCodeMap'],['../servicecom_1_1sun_1_1star_1_1sheet_1_1FormulaParser.html#a471ff54127cd34cf9f9807df69c5eec6',1,'com::sun::star::sheet::FormulaParser::OpCodeMap']]],
   ['openingflags_1',['OpeningFlags',['../structcom_1_1sun_1_1star_1_1ucb_1_1OpenCommandArgument3.html#a0c2301c92201398c62d785c267137e47',1,'com::sun::star::ucb::OpenCommandArgument3']]],
   ['options_2',['Options',['../structcom_1_1sun_1_1star_1_1embed_1_1InsertedObjectInfo.html#a3e5247ad3c34cd9aefbebfff90a20308',1,'com::sun::star::embed::InsertedObjectInfo']]]
 ];
